Learn R Programming

logistic4p (version 1.5)

logistic4p.fp.fn: Logistic Regression with both FP and FN Misclassification Correction

Description

logistic4p.fp.fn is used to fit a logistic regression model with both FP and FN misclassification parameters to a binary dependent variable.

Usage

logistic4p.fp.fn(x, y, initial, max.iter = 1000, epsilon = 1e-06, detail = FALSE)

Value

estimates

a named matrix of estimates including parameter estimates, standard errors, z-scores, and p-values.

n.iter

an integer giving the number of iteration used

d

the actual max absolute difference of the parameters of the last two iterations, d=max(|par.final-par_old|).

loglike

loglikelihood evaluated at the parameter estimates.

AIC

Akaike Information Criterion.

BIC

Bayesian Information Criterion.

converged

logical indicating whether the current procedure converged or not.

Arguments

x, y

x is a data frame or data matrix containing the predictor variables and y is the vector of outcomes. The number of rows in x must be the same as the length of y.

initial

starting values for the parameters in the model(FP,FN misclassification parameters and those in the linear predictor); if not specified, the default initials are 0 for the misclassification parameters and estimates obtained from the logistic regression for the parameters in the linear predictor.

max.iter

a positive integer giving the maximal number of iterations; if it is reached, the algorithm will stop.

epsilon

a positive convergence tolerance epsilon; the iterations converge when max(|par-par_old|)<epsilon.

detail

logical indicating if the output should be printed for each iteration.

Author

Haiyan Liu and Zhiyong Zhang

Examples

Run this code
if (FALSE) {
data(nlsy)
y=nlsy[,1]
x=nlsy[, -1]

mod=logistic4p.fp.fn(x,y)
}

Run the code above in your browser using DataLab