logistic4p.fp.fn is used to fit a logistic regression model with both FP and FN misclassification parameters to a binary dependent variable.
logistic4p.fp.fn(x, y, initial, max.iter = 1000, epsilon = 1e-06, detail = FALSE)
a named matrix of estimates including parameter estimates, standard errors, z-scores, and p-values.
an integer giving the number of iteration used
the actual max absolute difference of the parameters of the last two iterations, d=max(|par.final-par_old|).
loglikelihood evaluated at the parameter estimates.
Akaike Information Criterion.
Bayesian Information Criterion.
logical indicating whether the current procedure converged or not.
x is a data frame or data matrix containing the predictor variables and y is the vector of outcomes. The number of rows in x must be the same as the length of y.
starting values for the parameters in the model(FP,FN misclassification parameters and those in the linear predictor); if not specified, the default initials are 0 for the misclassification parameters and estimates obtained from the logistic regression for the parameters in the linear predictor.
a positive integer giving the maximal number of iterations; if it is reached, the algorithm will stop.
a positive convergence tolerance epsilon; the iterations converge when max(|par-par_old|)<epsilon.
logical indicating if the output should be printed for each iteration.
Haiyan Liu and Zhiyong Zhang
if (FALSE) {
data(nlsy)
y=nlsy[,1]
x=nlsy[, -1]
mod=logistic4p.fp.fn(x,y)
}
Run the code above in your browser using DataLab